@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
-
 from cubicweb import _
 from logilab.mtconverter import xml_escape
-from cubicweb.web.views import boxes
-from cubicweb.web.component import EntityCtxComponent, EmptyComponent
-from cubicweb.web.htmlwidgets import BoxLink, BoxWidget
+from cubicweb_web.views import boxes
+from cubicweb_web.component import EntityCtxComponent, EmptyComponent
+from cubicweb_web.htmlwidgets import BoxLink, BoxWidget
 from cubicweb.predicates import is_instance, authenticated_user
 
 
@@ -40,7 +38,7 @@ class TalkStatusBox(boxes.BoxTemplate):
                 box.append(
                     BoxLink(
                         _cw.build_url("view", rql=rql_ % state, vtitle=msg),
-                        xml_escape("%s %s" % (len(talks[state]), state)),
+                        xml_escape("{} {}".format(len(talks[state]), state)),
                     )
                 )
         box.render(w=self.w)
@@ -76,7 +74,7 @@ class ReviewStatusBox(boxes.BoxTemplate):
                 box.append(
                     BoxLink(
                         _cw.build_url("view", rql=rql_ % state, vtitle=msg),
-                        xml_escape("%s %s" % (len(talks[state]), state)),
+                        xml_escape("{} {}".format(len(talks[state]), state)),
                     )
                 )
         if box.items:
@@ -155,7 +153,7 @@ class SponsorBox(EntityCtxComponent):
             sponsors.sort(key=lambda x: lhash[x[0]])
             sponsors.reverse()
             _level = None
-            for (level, sponsor_eid, image_eid) in sponsors:
+            for level, sponsor_eid, image_eid in sponsors:
                 if level != _level:
                     w("<div>%s</div>" % level)
                     _level = level
