@@ -7,8 +7,8 @@ from logilab.common.date import date_range, todate, todatetime
 
 from cubicweb import _
 from cubicweb.predicates import adaptable, empty_rset
-from cubicweb.view import EntityView
-from cubicweb.web.views import calendar
+from cubicweb_web.view import EntityView
+from cubicweb_web.views import calendar
 
 
 # one day calendar view for day of conference
@@ -232,13 +232,13 @@ class OneDayCal(EntityView):
             )
             top = 100.0 * (start_hour + start_min / 60.0 - 8) / (20 - 8)
             left = width * task_desc.index
-            style = "height: %s%%; width: %s%%; top: %s%%; left: %s%%; " % (
+            style = "height: {}%; width: {}%; top: {}%; left: {}%; ".format(
                 height,
                 width,
                 top,
                 left,
             )
-            self.w('<div class="task %s" style="%s">' % (task_desc.color, style))
+            self.w('<div class="task {}" style="{}">'.format(task_desc.color, style))
             task.view("calendaritem", dates=False, w=self.w)
             params = self._cw.build_url_params(
                 year=date.year, week=date.isocalendar()[1]
