@@ -1,4 +1,4 @@
-from cubicweb.web import component
+from cubicweb_web import component
 from cubicweb.predicates import is_instance, match_user_groups, rql_condition
 
 
