@@ -1,5 +1,5 @@
 from cubicweb.predicates import is_instance
-from cubicweb.web.facet import RelationFacet, DateRangeFacet
+from cubicweb_web.facet import RelationFacet, DateRangeFacet
 
 # This selector is used by the TalkDate facet,
 # the start_time date is optional.
