@@ -1,4 +1,4 @@
-from cubicweb.web.views.formrenderers import EntityFormRenderer
+from cubicweb_web.views.formrenderers import EntityFormRenderer
 from cubicweb.predicates import match_user_groups
 
 
