@@ -1,7 +1,7 @@
 from cubicweb import _
-from cubicweb.web import Redirect
-from cubicweb.view import StartupView
-from cubicweb.web.views import startup
+from cubicweb_web import Redirect
+from cubicweb_web.view import StartupView
+from cubicweb_web.views import startup
 
 REPLACE = []
 
