@@ -1,13 +1,12 @@
-from __future__ import with_statement
 from logilab.mtconverter import xml_escape
 
 from cubicweb import _
 from cubicweb.predicates import is_instance, has_related_entities
 from cubicweb.predicates import authenticated_user
-from cubicweb.web.views.idownloadable import DownloadBox
-from cubicweb.web.component import EntityCtxComponent
-from cubicweb.web.views import primary, calendar
-from cubicweb.web.views.ajaxcontroller import ajaxfunc
+from cubicweb_web.views.idownloadable import DownloadBox
+from cubicweb_web.component import EntityCtxComponent
+from cubicweb_web.views import primary, calendar
+from cubicweb_web.views.ajaxcontroller import ajaxfunc
 
 
 class TalkPrimaryView(primary.PrimaryView):
@@ -59,7 +58,9 @@ class TalkPrimaryView(primary.PrimaryView):
                 )
             self.w("</span>")
         if entity.location:
-            self.w("<span> %s %s</span>" % (_("in room"), xml_escape(entity.location)))
+            self.w(
+                "<span> {} {}</span>".format(_("in room"), xml_escape(entity.location))
+            )
 
     def render_entity_attributes(self, entity):
         if entity.description:
@@ -149,7 +150,7 @@ class TalkCalendarItem(calendar.CalendarItemView):
             )
         )
         if talk.location:
-            self.w("<div>[%s %s]</div>" % (self._cw._("room"), talk.location))
+            self.w("<div>[{} {}]</div>".format(self._cw._("room"), talk.location))
 
 
 class AttachmentsDownloadBox(DownloadBox):
