@@ -3,8 +3,8 @@ from logilab.mtconverter import xml_escape
 
 from cubicweb import _
 from cubicweb.predicates import is_instance, rql_condition
-from cubicweb.view import EntityView
-from cubicweb.web.views import tabs
+from cubicweb_web.view import EntityView
+from cubicweb_web.views import tabs
 
 
 class TrackPrimaryView(tabs.TabbedPrimaryView):
