@@ -1,6 +1,6 @@
 from cubicweb import _
-from cubicweb.web import formfields as ff, formwidgets as fwdgs
-from cubicweb.web.views.workflow import WFHistoryVComponent, ChangeStateFormView
+from cubicweb_web import formfields as ff, formwidgets as fwdgs
+from cubicweb_web.views.workflow import WFHistoryVComponent, ChangeStateFormView
 from cubicweb.predicates import match_user_groups, rql_condition, is_instance
 from cubicweb_conference.views.forms import reviewers_vocabulary
 
