@@ -1,5 +1,3 @@
-from __future__ import with_statement
-
 from datetime import date
 
 from logilab.common.testlib import unittest_main
@@ -11,7 +9,7 @@ from utils import ConferenceTC
 
 class ConferenceSecurityTC(ConferenceTC):
     def setup_database(self):
-        super(ConferenceSecurityTC, self).setup_database()
+        super().setup_database()
         with self.admin_access.repo_cnx() as cnx:
             chair = self.create_user(cnx, "chair")
             reviewer = self.create_user(cnx, "reviewer")
@@ -46,7 +44,7 @@ class ConferenceSecurityTC(ConferenceTC):
 
 class TrackSecurityTC(ConferenceSecurityTC):
     def setup_database(self):
-        super(TrackSecurityTC, self).setup_database()
+        super().setup_database()
         with self.admin_access.repo_cnx() as cnx:
             self.track0 = cnx.create_entity(
                 "Track", title="my_track0", in_conf=self.conf
@@ -83,7 +81,7 @@ class TrackSecurityTC(ConferenceSecurityTC):
 
 class TalkSecurityTC(TrackSecurityTC):
     def setup_database(self):
-        super(TalkSecurityTC, self).setup_database()
+        super().setup_database()
         with self.admin_access.repo_cnx() as cnx:
             self.talk0 = cnx.create_entity(
                 "Talk", title="my_talk0", in_track=self.track0
