@@ -1,9 +1,8 @@
-from __future__ import with_statement
-
 from datetime import date
 from logilab.common.testlib import unittest_main
 
-from cubicweb.web.views import actions, workflow
+from cubicweb.devtools import BASE_URL
+from cubicweb_web.views import actions, workflow
 
 from cubicweb_conference.views import actions as confactions
 
@@ -12,7 +11,7 @@ from utils import ConferenceTC
 
 class ConferenceActionsTC(ConferenceTC):
     def setup_database(self):
-        super(ConferenceActionsTC, self).setup_database()
+        super().setup_database()
         with self.admin_access.repo_cnx() as cnx:
             self.create_user(cnx, "guest", groups=("guests",))
             self.create_user(cnx, "user")
@@ -54,10 +53,10 @@ class ConferenceActionsTC(ConferenceTC):
                 [
                     (
                         "add Track in_conf Conference object",
-                        "http://testing.fr/cubicweb/add/Track"
-                        "?__linkto=in_conf%%3A%(eid)s%%3Asubject&"
-                        "__redirectpath=conference%%2F%(url)s&"
-                        "__redirectvid=" % {"eid": conf.eid, "url": conf.url_id},
+                        f"{BASE_URL}add/Track"
+                        f"?__linkto=in_conf%%3A%(eid)s%%3Asubject&"
+                        f"__redirectpath=conference%%2F%(url)s&"
+                        f"__redirectvid=" % {"eid": conf.eid, "url": conf.url_id},
                     ),
                 ],
             )
@@ -83,10 +82,10 @@ class ConferenceActionsTC(ConferenceTC):
                 [
                     (
                         "add Track in_conf Conference object",
-                        "http://testing.fr/cubicweb/add/Track"
-                        "?__linkto=in_conf%%3A%(eid)s%%3Asubject&"
-                        "__redirectpath=conference%%2F%(url)s&"
-                        "__redirectvid=" % {"eid": conf.eid, "url": conf.url_id},
+                        f"{BASE_URL}add/Track"
+                        f"?__linkto=in_conf%%3A%(eid)s%%3Asubject&"
+                        f"__redirectpath=conference%%2F%(url)s&"
+                        f"__redirectvid=" % {"eid": conf.eid, "url": conf.url_id},
                     ),
                 ],
             )
@@ -111,7 +110,7 @@ class ConferenceActionsTC(ConferenceTC):
 
 class TrackActionsTC(ConferenceActionsTC):
     def setup_database(self):
-        super(TrackActionsTC, self).setup_database()
+        super().setup_database()
         with self.admin_access.repo_cnx() as cnx:
             self.track = cnx.create_entity(
                 "Track", title="a track", in_conf=self.conf
